/**
 * 图表配置相关的类型定义
 *
 * @author 海狸
 */
/**
 * 数值格式化配置
 */
export interface NumberFormat {
    /** 模式：默认为自动适配。0 自动适配；1 自定义模式；2 手工输入 */
    formatModal: '0' | '1' | '2';
    /**
     * 对应 原来为 serie.fmtType
     * formatModal = 0 (自动适配)下, 对应可取值为: CN 中文（默认） KMG 英文 CNT 繁体
     * formatModal = 1 (自定义模式)下, 对应可取值为: None
     * formatModal = 2 (手工输入)下, 对应可取值为: Custom
     */
    fmtType: 'CN' | 'KMG' | 'CNT' | 'Custom' | 'None';
    /** 值类型，默认为数值。0 数值；1 百分比 */
    valueModal: '0' | '1';
    /** 小数位，默认不选择。原来为 serie.decimalPlaces */
    decimalPlaces: '' | '0' | '1' | '2' | '3' | '4' | '5';
    /** 是否使用千分位分隔符，默认不使用。原来为 serie.thousandth */
    thousandth: boolean;
    /** 手工输入格式，原来为 serie.fmt */
    fmt: string;
    /** 数据单位 */
    magnitudeFormat?: number;
    /** 数据格式 */
    dataMagnitude?: string;
}
export declare enum ImageDisplayMode {
    LEFT = 0,
    CENTER = 1,
    RIGHT = 2,
    CLIP = 3,
    STRETCH = 4
}
/** 时间维度对应的环比同比字段
 * 日：昨日环比、上周同比、上月同比、去年同比，默认昨日环比，上周同比
 * 周: 上周环比、年同比，默认选择『上周环比』
 * 月：上月环比、年同比，默认选择『上月环比』
 * 季度：上季环比、年同比，默认选择『上季环比』
 * 年：年环比
 */
export declare const ConstastTypeMap: {
    dateRegion: string[];
    weekRegion: string[];
    monthRegion: string[];
    quarterRegion: string[];
    yearRegion: string[];
};
