/**
 * @author 海狸
 * @description 组件 props 接口
 */
import { NumberFormat } from './chart-config';
import { DataCell, AreaModel, GlobalConfig } from './standard-model';
export interface ComponentPropsGlobalConfig extends GlobalConfig {
    /**
     * @deprecated
     * 预览态 编辑态
     * */
    renderMode?: 'render' | 'edit';
}
/**
 * 图表选中, 包含下钻/联动/跳转
 */
interface ComponentPropsActionSelect {
    type: 'select';
    payload: {
        dataIndex: number;
    };
}
/**
 * 图表取消选中, 包含下钻/联动/跳转
 */
interface ComponentPropsActionCancelSelect {
    type: 'cancelSelect';
}
/**
 * 修改 viewConfig 的值
 */
interface ComponentPropsActionChangeViewConfig {
    type: 'changeViewConfig';
    payload: {
        [key: string]: any;
    };
}
/**
 * 取消下钻
 */
interface ComponentPropsActionCancelDrill {
    type: 'cancelDrill';
}
/**
 * 取消联动
 */
interface ComponentPropsActionCancelLinkage {
    type: 'cancelLinkage';
}
export declare type ComponentPropsDispatch = (param: ComponentPropsActionSelect | ComponentPropsActionCancelSelect | ComponentPropsActionChangeViewConfig | ComponentPropsActionCancelDrill | ComponentPropsActionCancelLinkage) => void;
interface ComponentPropsFieldSettingConfig {
    /** 字段别名 */
    aliasName: string;
    /** 是否有更改 */
    nameChangedFlag: boolean;
    /** 数值显示格式 */
    numberFormat: NumberFormat;
    [key: string]: any;
}
export interface ComponentPropsColorSeries {
    /** 色系key */
    key: string;
    /** 色系名称 */
    name: string;
    /** 色系颜色 */
    colors: string[];
}
export interface ComponentPropsSkin {
    /** 色系key */
    key: 'black' | 'default';
}
export interface ComponentPropsViewConfig {
    /** 标题 */
    caption?: string;
    /** 主题 */
    chartColorSeries?: ComponentPropsColorSeries;
    /** 皮肤 */
    chartSkin?: ComponentPropsSkin;
    /** 展示标题 */
    title?: {
        /** 展示主标题/备注 */
        show: boolean;
        /** 标题备注 */
        viceName?: string;
        /** 标题颜色 */
        color?: string;
        /** 展示链接跳转 */
        showLink?: boolean;
        /** 链接地址 */
        link?: string;
        /** 链接文案 */
        linkName?: string;
    };
    /** 列设置 */
    fieldSettingMap?: {
        [fieldId: string]: ComponentPropsFieldSettingConfig;
    };
    /** 宽度 */
    width?: number;
    /** 高度 */
    height?: number;
    [key: string]: any;
}
/**
 * bi 组件通用属性模型
 */
export interface ComponentProps {
    /** 自定义组件实例 id */
    id: string;
    /** 样式面板配置 */
    viewConfig: ComponentPropsViewConfig;
    /** 数据面板配置 */
    dataConfig: AreaModel[];
    /** 高级面板配置 */
    advancedConfig: object;
    /** 图表全局配置 */
    globalConfig: ComponentPropsGlobalConfig;
    /** 数据 */
    data: Pick<DataCell, 'fieldId' | 'geoInfo' | 'originValue' | 'value'>[][];
    /** 操作 */
    dispatch?: ComponentPropsDispatch;
}
export {};
