/**
 * @author 墨辞
 * @description 数据面板的配置接口定义
 */
/**
 * 字段类型枚举
 * - dimension: 维度类型
 * - measure: 度量类型
 * - all: 任意类型
 */
export declare type DataSchemaRuleType = 'dimension' | 'measure' | 'all';
/**
 * 区块功能枚举
 * - column: 设置为列，RuleType 一般对应于度量类型
 * - row: 设置为行，RuleType 一般对应于维度类型
 * - drill: 设置为钻取维度，RuleType必须是维度类型
 * - filters: 设置为过滤器，RuleType可以是维度或者度量
 * */
export declare type DataSchemaAreaType = 'column' | 'row' | 'drill' | 'filters';
/**
 * 区块id枚举
 * - area_column: 列id
 * - area_row: 行id
 * - drill: 下钻id
 * - filters: 过滤器id
 * */
export declare type DataSchemaAreaId = 'area_column' | 'area_row' | 'drill' | 'filters';
export interface DataSchemaBase {
    /** Schema所包含的区块 */
    area: DataSchemaArea[];
    /** 是否去重 */
    /** 是否自动刷新，-1表示不自动刷新，设置为数字代表每多少秒刷新一次 */
    /** 最大的取数数量限制 */
    limitNum: number;
}
export interface DataSchemaArea {
    /** id */
    id?: DataSchemaAreaId;
    /**
     * 设置轴查询时对应的类型
     * */
    queryAxis?: DataSchemaAreaType;
    /** 区块名称  */
    areaName: string;
    /** 区块字段列表  */
    columnList?: any[];
    /** 区块配置规则  */
    rule: DataSchemaRule;
    /** 其他扩展字段 */
    [key: string]: any;
}
export interface DataSchemaRule {
    /** 允许添加的字段类型  */
    type: DataSchemaRuleType;
    /** 是否允许为空  */
    required?: boolean;
    /** 最多添加的字段个数 */
    maxColNum?: number;
    /** 是否显示该区块 */
    /** 其他扩展字段 */
    [key: string]: any;
}
/**
 * 样式面板配置
 */
export interface DataSchema {
    schema: DataSchemaBase;
}
