/**
 * @author 海狸
 * @description 样式面板配置
 */
/// <reference types="react" />
export declare type StyleSchemaDependId = number | string;
/**  depend 类型 */
interface ValueDepend {
    id: StyleSchemaDependId;
    value: any | any[];
}
interface PatternDepend {
    id?: StyleSchemaDependId;
    pattern?: string;
}
declare type StyleSchemaBaseDepend = ValueDepend | PatternDepend;
interface StyleSchemaAndDepend {
    $and?: StyleSchemaDepend[];
}
interface StyleSchemaOrDepend {
    $or?: StyleSchemaDepend[];
}
export declare type StyleSchemaDepend = StyleSchemaBaseDepend & StyleSchemaAndDepend & StyleSchemaOrDepend;
/**  校验规则配置项类型定义 */
export interface StyleSchemaValidationRule {
    /**  必要属性（除存在代理校验属性外的情况下 必须声明）：校验错误信息 */
    message?: string;
    /**  校验属性（除存在代理校验属性外的情况下 必须且仅可声明其中一个 参考 async-validator） */
    [rule: string]: any;
    /**  代理校验属性（当此属性有效时 其他属性无效 可不声明）：代理校验函数名 */
    funcName?: string;
}
/** 校验结果类型定义（用于 onChange 函数） */
export interface StyleSchemaValidationResult {
    /** 是否通过校验 */
    pass: boolean;
    /** 不通过校验时 返回详细字段名和信息 若校验通过则空 */
    details: {
        field: string;
        message: string;
    }[];
}
export interface StyleSchemaValidation {
    [validateFuncName: string]: (rule?: any, currentValue?: any, extras?: {
        data?: any;
        schema?: Schema;
        keyPaths?: string[];
    }) => string | Promise<any> | void;
}
export interface StyleSchema {
    /** styleSchema 配置 */
    schema: StyleSchemaBase;
    /** 自定义编辑器 */
    localEditors?: {
        [key: string]: React.ComponentType<any>;
    };
    /** 自定义校验函数 */
    validation?: StyleSchemaValidation;
    /** change 事件处理函数 */
    onChange?: (data?: any, currentSchema?: Schema, keyPaths?: string[], validation?: StyleSchemaValidationResult) => void;
}
/** styleSchema 配置 */
export interface StyleSchemaBase<P = any, T = string> {
    /** 使用的子组件类型 */
    type: T;
    /** 标题文案 */
    title?: string;
    /** 标题对齐方式 */
    titleAlign?: 'left' | 'center' | 'right';
    /** 子字段 */
    properties?: StyleSchemaProperties;
    /** 容器类名 */
    className?: string;
    /** 描述文案 */
    description?: string;
    /** 显示顺序 */
    propertyOrder?: number;
    /** 字段的 id 标识符 */
    id?: StyleSchemaDependId;
    /** 是否隐藏 */
    hide?: boolean;
    /** 显隐依赖 */
    visibleDepends?: StyleSchemaDepend[];
    /** 是否禁用 */
    disabled?: boolean;
    /** 禁用依赖 */
    disableDepends?: StyleSchemaDepend[];
    /** 禁用时隐藏 */
    hideIfDisable?: boolean;
    /** 校验规则 */
    validation?: StyleSchemaValidationRule[];
    /** 是否显示必填星号标记 */
    showRequiredMark?: boolean;
    /** 是否显示校验错误信息 */
    hideValidateTips?: boolean;
    /** 自定义默认值 */
    defaultValue?: any;
    /** 子组件 props */
    props?: P;
    /** 字段重定向（点分字符串） */
    redirect?: string;
    /** 关联 data */
    relatedToData?: boolean;
    /** 后缀 比如 xx: [select/input 组件] 天  */
    suffix?: string;
    /** 布局属性 */
    grid?: {
        row: number;
        col: number;
    };
}
/** type 为 object 的配置 */
export interface StyleSchemaObject extends StyleSchemaBase {
    type: 'object';
    props?: {
        /** 分组类型 */
        mode?: 'tabs' | 'collapse';
    };
    /** 提示气泡 */
    info?: string;
}
/** type 为 array 的配置 */
export interface StyleSchemaArray extends StyleSchemaBase {
    type: 'array';
    /** 数组元素默认值 */
    arrayItemDefaultValue?: any;
}
declare type Schema = StyleSchemaObject | StyleSchemaArray | StyleSchemaBase;
/** properties 属性 */
export declare type StyleSchemaProperties = {
    [key: string]: Schema;
} | string;
export {};
